@@ -1,3 +1,27 @@
+#******************************************************************************* 
+#
+# Estimation for Multivariate Normal Data with Monotone Missingness
+# Copyright (C) 2007, University of Cambridge
+# 
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+# 
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+# 
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#
+# Questions? Contact Robert B. Gramacy (bobby@statslab.cam.ac.uk)
+#
+#*******************************************************************************
+
+
 ## monomvn:
 ##
 ## Under a MVN model, calculate the MLE of the mean and variance
@@ -54,6 +78,10 @@ function(y, pre=TRUE,
     if(length(verb) != 1 || verb < 0)
       stop("verb should be a positive scalar")
 
+    ## check quiet argument
+    if(length(quiet) != 1 || !is.logical(quiet))
+      stop("quiet should be a logical scalar")
+
     ## save the call
     cl <- match.call()
     
